@@ -2,35 +2,34 @@
 # Kernel/Language/pt.pm - provides pt language translation
 # Copyright (C) 2004-2007 CAT - Filipe Henriques <filipehenriques at ip.pt>
 # --
-# $Id: pt.pm,v 1.49.2.1 2007/12/10 08:44:44 mh Exp $
+# $Id: pt.pm,v 1.67 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Language::pt;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.49.2.1 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.67 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:22:15 2007
+    # Last translation file sync: Fri May 16 14:08:50 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%Y-%M-%D %T';
-    $Self->{DateFormatLong} = '%A, %D de %B de %Y, %T';
-    $Self->{DateFormatShort} = '%Y-%M-%D';
-    $Self->{DateInputFormat} = '%Y-%M-%D';
+    $Self->{DateFormat}          = '%Y-%M-%D %T';
+    $Self->{DateFormatLong}      = '%A, %D de %B de %Y, %T';
+    $Self->{DateFormatShort}     = '%Y-%M-%D';
+    $Self->{DateInputFormat}     = '%Y-%M-%D';
     $Self->{DateInputFormatLong} = '%Y-%M-%D - %T';
 
     $Self->{Translation} = {
@@ -104,6 +103,7 @@ sub Data {
         'please do not edit!' => 'por favor no editar!',
         'AddLink' => 'Adicionar Ligao',
         'Link' => 'Ligar',
+        'Unlink' => '',
         'Linked' => 'Ligado',
         'Link (Normal)' => 'Ligar (Normal)',
         'Link (Parent)' => 'Ligar (Ascendente)',
@@ -245,6 +245,8 @@ sub Data {
         'Mobile' => 'Movel',
         'Zip' => 'Codigo Postal',
         'City' => 'Cidade',
+        'Location' => 'Localizao',
+        'Street' => 'Rua',
         'Country' => 'Pais',
         'installed' => 'instalado',
         'uninstalled' => 'desinstalado',
@@ -253,13 +255,23 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => 'No existe pacotes no Framework pedido neste Repositrio, mas pacotes de outro Frameworks',
         'No Packages or no new Packages in selected Online Repository!' => 'No existe pacotes no Repositrio selecionado',
         'printed at' => 'imprimido em',
+        'Dear Mr. %s,' => '',
+        'Dear Mrs. %s,' => '',
+        'Dear %s,' => '',
+        'Hello %s,' => '',
+        'This account exists.' => '',
+        'New account created. Sent Login-Account to %s.' => '',
+        'Please press Back and try again.' => '',
+        'Sent password token to: %s' => '',
+        'Sent new password to: %s' => '',
+        'Invalid Token!' => '',
 
         # Template: AAAMonth
         'Jan' => 'Jan',
         'Feb' => 'Fev',
         'Mar' => 'Mar',
         'Apr' => 'Abr',
-        'May' => 'Mai',
+        'May' => 'Maio',
         'Jun' => 'Jun',
         'Jul' => 'Jul',
         'Aug' => 'Ago',
@@ -271,7 +283,6 @@ sub Data {
         'February' => 'Fevereiro',
         'March' => 'Maro',
         'April' => 'Abril',
-        'May' => 'Maio',
         'June' => 'Junho',
         'July' => 'Julho',
         'August' => 'Agosto',
@@ -384,6 +395,7 @@ sub Data {
         'Move' => 'Mover',
         'Queue' => 'Fila',
         'Priority' => 'Prioridade',
+        'Priority Update' => '',
         'State' => 'Estado',
         'Compose' => 'Compr',
         'Pending' => 'Pendncias',
@@ -452,6 +464,7 @@ sub Data {
         'Phone-Ticket' => 'Telefonema',
         'Search Tickets' => 'Procurar Tickets',
         'Edit Customer Users' => 'Editar Utilizadores Clientes',
+        'Edit Customer Company' => '',
         'Bulk-Action' => 'Em Lote',
         'Bulk Actions on Tickets' => 'Aces em Lote sobre Tickets',
         'Send Email and create a new Ticket' => 'Enviar mensagem e criar novo Ticket',
@@ -550,6 +563,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Customer request via web.',
         'History::TicketLinkAdd' => 'Adicionado novo link ao ticket "%s".',
         'History::TicketLinkDelete' => 'Apagado link de ticket "%s".',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'Domingo',
@@ -582,6 +597,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => 'Gesto de Utilizadores de Companhias',
+        'Search for' => 'Procurar por',
         'Add Customer Company' => 'Adicione Utilizador de Companhia',
         'Add a new Customer Company.' => 'Adicione um novo Utilizador de Companhia',
         'List' => 'Listar',
@@ -590,7 +606,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Gesto de Utilizadores de Cliente',
-        'Search for' => 'Procurar por',
         'Add Customer User' => 'Adicione Utilizador de Cliente',
         'Source' => 'Fonte',
         'Create' => 'Criar',
@@ -609,14 +624,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
-        # Template: AdminCustomerUserServiceChangeForm
+        # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => '',
-        'Select the customeruser:service relations.' => '',
-        'Allocate services to CustomerUser' => '',
-        'Allocate CustomerUser to service' => '',
-
-        # Template: AdminCustomerUserServiceForm
+        'CustomerUser' => 'Utilizador Cliente',
+        'Service' => 'Servio',
         'Edit default services.' => '',
+        'Search Result' => 'Resultado de Procura',
+        'Allocate services to CustomerUser' => '',
+        'Active' => 'Activo',
+        'Allocate CustomerUser to service' => '',
 
         # Template: AdminEmail
         'Message sent to' => 'Mensagem enviada para',
@@ -639,6 +655,7 @@ sub Data {
         '(e. g. 234321)' => '(ex., 234321)',
         'Customer User Login' => 'Nome de Utilizador de Cliente',
         '(e. g. U5150)' => '(ex., U5150)',
+        'SLA' => '',
         'Agent' => 'Agente',
         'Ticket Lock' => 'Bloqueio de Ticket',
         'TicketFreeFields' => 'TicketCamposLivres',
@@ -646,10 +663,16 @@ sub Data {
         'No create time settings.' => 'No existe definies de Tempo Criados',
         'Ticket created' => 'Ticket criado',
         'Ticket created between' => 'Ticket criado entre',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Pending Times' => 'Tempo Pendente',
         'No pending time settings.' => 'No existe definies de Tempo Pendente',
         'Ticket pending time reached' => 'Tempo de pendencia do ticket atingido',
         'Ticket pending time reached between' => 'Tempo de pendencia do ticket entre',
+        'New Service' => '',
+        'New SLA' => '',
         'New Priority' => 'Nova Prioridade',
         'New Queue' => 'Nova Fila',
         'New State' => 'Novo Estado',
@@ -657,7 +680,9 @@ sub Data {
         'New Owner' => 'Novo Proprietrio',
         'New Customer' => 'Novo Cliente',
         'New Ticket Lock' => 'Novo Bloqueio do Ticket',
-        'CustomerUser' => 'Utilizador Cliente',
+        'New Type' => '',
+        'New Title' => '',
+        'New Type' => '',
         'New TicketFreeFields' => 'Novo Campo livre',
         'Add Note' => 'Adicionar Nota',
         'CMD' => '',
@@ -690,6 +715,14 @@ sub Data {
         'System Log' => 'Registo do Sistema',
         'Time' => 'Tempo',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => '',
+        'Host' => 'Anfitrio',
+        'Trusted' => 'Confivel',
+        'Dispatching' => 'Despachando',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Todas as mensagens recebidas correspondentes a uma com uma conta sero despachados para a fila selecionada!',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
+
         # Template: AdminNavigationBar
         'Users' => 'Utilizadores',
         'Groups' => 'Grupos',
@@ -744,6 +777,10 @@ sub Data {
         'Min Response' => 'Resposta minima',
         'Max Response' => 'Resposta maxima',
         'Average Response' => 'Media de Resposta',
+        'Period' => '',
+        'Min' => '',
+        'Max' => '',
+        'Average' => '',
 
         # Template: AdminPGPForm
         'PGP Management' => 'Gesto de PGP',
@@ -755,14 +792,6 @@ sub Data {
         'Expires' => 'Expira',
         'In this way you can directly edit the keyring configured in SysConfig.' => 'Desta forma pode editar directamente o anel de chaves configurado no SysConfig',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'Gesto de Contas POP3',
-        'Host' => 'Anfitrio',
-        'Trusted' => 'Confivel',
-        'Dispatching' => 'Despachando',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Todas as mensagens recebidas correspondentes a uma com uma conta sero despachados para a fila selecionada!',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => 'Gesto de Filtros do Chefe do Correio',
         'Filtername' => 'Nome do Filtro',
@@ -782,9 +811,13 @@ sub Data {
         'Sub-Queue of' => 'Subfila de',
         'Unlock timeout' => 'Tempo de desbloqueio',
         '0 = no unlock' => '0 = sem desbloqueio',
+        'Only business hours are counted.' => '',
         'Escalation - First Response Time' => 'Primeiro tempo de resposta',
         '0 = no escalation' => '0 = sem escalamento',
+        'Only business hours are counted.' => '',
+        'Notify by' => '',
         'Escalation - Update Time' => 'Tempo de actualizao',
+        'Notify by' => '',
         'Escalation - Solution Time' => 'Tempo de soluo',
         'Follow up Option' => 'Opo de Seguimento',
         'Ticket lock after a follow up' => 'Bloqueio do ticket aps seguimento',
@@ -844,7 +877,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => 'Papeis <-> Gesto de Utilizadores',
-        'Active' => 'Activo',
         'Select the role:user relations.' => 'Seleccione as relaes papel:utilizador',
 
         # Template: AdminRoleUserForm
@@ -855,7 +887,7 @@ sub Data {
         'Add a new Salutation.' => 'Adicionar nova Apresentao',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => 'Caixa de Seleco',
+        'SQL Box' => '',
         'Limit' => 'Limite',
         'Go' => '',
         'Select Box Result' => 'Selecione a Caixa de Resultado',
@@ -864,7 +896,6 @@ sub Data {
         'Service Management' => 'Gesto de servio',
         'Add Service' => 'Adicionar Servio',
         'Add a new Service.' => 'Adicionar novo servio',
-        'Service' => 'Servio',
         'Sub-Service of' => 'Sub-servio de',
 
         # Template: AdminSession
@@ -885,10 +916,6 @@ sub Data {
         'SLA Management' => 'Gesto de SLA',
         'Add SLA' => 'Adicionar SLA',
         'Add a new SLA.' => 'Adicionar novo SLA',
-        'SLA' => '',
-        'First Response Time' => 'Primeiro tempo de resposta',
-        'Update Time' => 'Tempo de actualizao',
-        'Solution Time' => 'Tempo de soluo',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => '',
@@ -1043,7 +1070,7 @@ sub Data {
         'Scale' => 'Escala',
         'minimal' => 'Minima',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => 'Relembre-se que o valor da escala tem de ser superior ao valor maximo para o eixo dos X',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => 'Selecione o elemento que vai ser usado no eixo dos X',
@@ -1065,7 +1092,7 @@ sub Data {
 
         # Template: AgentStatsView
         'Export Config' => 'Exportar configuraao',
-        'Informations about the Stat' => 'Informaoes sobre estatisticas',
+        'Information about the Stat' => 'Informaoes sobre estatisticas',
         'Exchange Axis' => 'Troca de eixos',
         'Configurable params of static stat' => 'Parametros configuraveis de estatisticas estaticas',
         'No element selected.' => 'Sem elemento selecionado',
@@ -1123,6 +1150,17 @@ sub Data {
         'Refresh' => 'Actualizar',
         'Clear To' => 'Clear para',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => '',
+        'Escalation' => '',
+        'Today' => '',
+        'Tomorrow' => '',
+        'Next Week' => '',
+        'up' => 'crescente',
+        'down' => 'decrescente',
+        'Escalation' => '',
+        'Locked' => 'Bloqueado',
+
         # Template: AgentTicketForward
         'Article type' => 'Tipo de artigo',
 
@@ -1143,8 +1181,6 @@ sub Data {
         'Reminder' => 'Lembretes',
         'Sort by' => 'Ordenado pela',
         'Order' => 'Ordem',
-        'up' => 'crescente',
-        'down' => 'decrescente',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => 'Juntar Ticket',
@@ -1174,7 +1210,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => 'Informao de Ticket',
         'Accounted time' => 'Tempo contabilizado',
-        'Escalation in' => 'Escalado em',
+        'First Response Time' => 'Primeiro tempo de resposta',
+        'Update Time' => 'Tempo de actualizao',
+        'Solution Time' => 'Tempo de soluo',
         'Linked-Object' => 'Objecto-Ligado',
         'Parent-Object' => 'Objecto-Ascendente',
         'Child-Object' => 'Objecto-Descendente',
@@ -1209,29 +1247,35 @@ sub Data {
         'Search-Template' => 'Modelo de procura',
         'TicketFreeText' => 'Texto Livre do Ticket',
         'Created in Queue' => 'Criado na Fila',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Result Form' => 'Formato do resultado',
         'Save Search-Profile as Template?' => 'Guardar Perfil de Procura como Modelo?',
         'Yes, save it with name' => 'Sim, guardar com o nome',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => 'Resultado de Procura',
         'Change search options' => 'Alterar opes de procura',
 
         # Template: AgentTicketSearchResultPrint
 
         # Template: AgentTicketSearchResultShort
-        'U' => 'C',
-        'D' => '',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => 'Visualizao do Estado dos Tickets',
         'Open Tickets' => 'Tickets Abertos',
-        'Locked' => 'Bloqueado',
 
         # Template: AgentTicketZoom
+        'Expand View' => '',
+        'Collapse View' => '',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1299,15 +1343,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => 'Instalador Web',
+        'Welcome to %s' => 'Bem Vindo a %s',
         'Accept license' => 'Aceitar licena',
         'Don\'t accept license' => 'Nao aceitar licena',
         'Admin-User' => 'Utilizador de Admin',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => '',
         'Admin-Password' => 'Password de admnistrador',
-        'your MySQL DB should have a root password! Default is empty!' => 'a sua Base de Dados MySQL deve ter uma palavra-passe de administrao! Por omisso ela est vazia!',
         'Database-User' => 'Utilizador da Base de Dados',
         'default \'hot\'' => 'por omisso \'hot\'',
         'DB connect host' => 'Anfitrio para ligaes  Base de Dados',
         'Database' => 'Base de dados',
+        'Default Charset' => 'Codificao por Omisso',
+        'utf8' => '',
         'false' => 'falso',
         'SystemID' => 'ID do sistema',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(A identidade do sistema. Cada nmero de ticket e cada id. da sesso http, inicia com este nmero)',
@@ -1322,7 +1369,6 @@ sub Data {
         'Logfile' => 'Ficheiro de Log',
         '(Logfile just needed for File-LogModule!)' => '(Ficheiro de registo para File-LogModule)',
         'Webfrontend' => 'Interface Web',
-        'Default Charset' => 'Codificao por Omisso',
         'Use utf-8 it your database supports it!' => 'Usar UTF-8 se a base de dados o suportar',
         'Default Language' => 'Idioma por Omisso',
         '(Used default language)' => '(Idioma por omisso utilizado)',
@@ -1332,11 +1378,9 @@ sub Data {
         'Restart your webserver' => 'Reinicie o seu servidor Web',
         'After doing so your OTRS is up and running.' => 'Depois de o fazer, o seu OTRS estar funcional.',
         'Start page' => 'Pgina inicial',
-        'Have a lot of fun!' => 'Divirta-se!',
         'Your OTRS Team' => 'A sua Equipa OTRS',
 
         # Template: Login
-        'Welcome to %s' => 'Bem Vindo a %s',
 
         # Template: Motd
 
@@ -1367,20 +1411,21 @@ sub Data {
         'Multiplier:' => 'Multiplicador:',
         'Ticket Number Generator' => 'Gerador de Nmeros de Tickets',
         '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Identificao do ticket. Algumas pessoas usam \'Ticket#\', \'Chamada#\' or \'MeuTicket#\')',
-        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'Desta forma pode alterar directamente o keyring configurado no Kernel/Config.pm',
         'Create new Phone Ticket' => 'Criar novo Ticket via Telefone',
+        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'Desta forma pode alterar directamente o keyring configurado no Kernel/Config.pm',
         'Symptom' => 'Sintoma',
+        'U' => 'C',
         'A message should have a To: recipient!' => 'Uma mensagem deve possuir um Para: destinatrio!',
         'Site' => 'Pgina',
         'Customer history search (e. g. "ID342425").' => 'Procura no histrico do cliente (e.g., "ID342425")',
-        'Close!' => 'Fechar!',
         'for agent firstname' => 'para o nome prprio do agente',
+        'Close!' => 'Fechar!',
         'The message being composed has been closed.  Exiting.' => 'A mensagem sendo composta foi fechada. Saindo.',
         'A web calendar' => 'Um calendrio na Web',
         'to get the realname of the sender (if given)' => 'para obter o nome do remetente (se indicado na mensagem)',
         'OTRS DB Name' => 'Nome da Base de Dados OTRS',
-        'Options of the ticket data (e. g. &lt;OTRS_TICKET_TicketNumber&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)' => '',
         'Notification (Customer)' => 'Notificaao (cliente)',
+        'Options of the ticket data (e. g. &lt;OTRS_TICKET_TicketNumber&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)' => '',
         'PGP Key' => 'Chave PGP',
         'Select Source (for add)' => 'Seleccionar fonte (para a adio)',
         'Options of the ticket data (e. g. &lt;OTRS_TICKET_Number&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)' => 'Opes dos dados do ticket (e.g., &lt;OTRS_TICKET_Number&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)',
@@ -1388,6 +1433,7 @@ sub Data {
         'Home' => 'Incio',
         'System History' => 'Histrico do Sistema',
         'customer realname' => 'nome do cliente',
+        'First Response' => 'Primeira Reposta',
         'Pending messages' => 'Mensagens pendentes',
         'Modules' => 'Mdulos',
         'for agent login' => 'para o nome de utilizador do agente',
@@ -1409,7 +1455,7 @@ sub Data {
         'SMIME Certificate Upload' => 'Carregamento de Certificado SMIME',
         'Create new database' => 'Criar nova base de dados',
         'A message must be spell checked!' => 'Tem de verificar a ortografia da mensagem!',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'Seu email com o nmero de ticket "<OTRS_TICKET>" foi devolvido para "<OTRS_BOUNCE_TO>". Contate este endereo para mais informaes.',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'Seu email com o nmero de ticket "<OTRS_TICKET>" foi devolvido para "<OTRS_BOUNCE_TO>". Contate este endereo para mais informaes.',
         'ArticleID' => 'ID de Artigo',
         'A message should have a body!' => 'A mensagem deve conter um texto!',
         'All Agents' => 'Todos os Agentes',
@@ -1417,17 +1463,18 @@ sub Data {
         'Select:' => 'Seleccionar:',
         'No * possible!' => 'No so possveis *!',
         'PostMaster Filter' => 'Filtros do Chefe do Correio',
-        'PostMaster POP3 Account' => 'Conta do Chefe do Correio',
         'Options of the current user who requested this action (e. g. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)' => 'Opoes do user actual que pediu esta aco',
+        'PostMaster POP3 Account' => 'Conta do Chefe do Correio',
         'Message for new Owner' => 'Mensagem para o novo Proprietrio',
         'to get the first 5 lines of the email' => 'para obter as 5 primeiras linhas da mensagem de correio electrnico',
         'OTRS DB Password' => 'Palavra-passe da Base de Dados OTRS',
         'Last update' => 'ltima actualizao',
         'Sorry, feature not active!' => 'Lamentamos, caracterstica no activa!',
         'to get the first 20 character of the subject' => 'para obter os 20 primeiros caracteres do assunto',
+        'Select the customeruser:service relations.' => '',
         'DB Admin Password' => 'Palavra-passe de Administrador da Base de Dados',
-        'Drop Database' => 'Apagar Base de Dados',
         'Advisory' => 'Recomendao',
+        'Drop Database' => 'Apagar Base de Dados',
         'FileManager' => 'Gestor de Ficheiros',
         'Pending type' => 'Tipo de pendncia',
         'Comment (internal)' => 'Comentrio (interno)',
@@ -1457,13 +1504,14 @@ sub Data {
         'WebWatcher' => 'Observador da Web',
         'Finished' => 'Terminado',
         'Split' => 'Dividir',
-        'All messages' => 'Todas as mensagens',
+        'D' => '',
         'System Status' => 'Estado do Sistema',
+        'All messages' => 'Todas as mensagens',
         'Artefact' => 'Artefacto',
         'A article should have a title!' => 'Um artigo tem de ter um ttulo!',
         'Benchmark' => 'Desempenho',
-        'Event' => 'Evento',
         'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => 'Opes de Configurao (Ex. &lt;OTRS_CONFIG_HttpType&gt;)',
+        'Event' => 'Evento',
         'Update:' => 'Actualizar:',
         'don\'t accept license' => 'no aceitar licena',
         'A web mail client' => 'Um cliente de correio electrnico na Web',
@@ -1475,15 +1523,19 @@ sub Data {
         'Solution' => 'Soluo',
         'Requests:' => 'Pedidos:',
         'QueueView' => 'Filas',
+        'Select Box' => 'Caixa de Seleco',
         'SMIME Certificate' => 'Certificado SMIME',
         'Welcome to OTRS' => 'Bem-vindo ao OTRS',
+        'Escalation in' => 'Escalado em',
         'Delete old database' => 'Eliminar base de dados antiga',
         'sort downward' => 'ordenar decrescentemente',
         'You need to use a ticket number!' => 'Ter de usar um numero de ticket!',
         'Ticket %s locked.' => 'Ticket %s bloqueado.',
         'A web file manager' => 'Um gestor de ficheiros na Web',
+        'Have a lot of fun!' => 'Divirta-se!',
         'send' => 'enviar',
         'Note Text' => 'Nota',
+        'POP3 Account Management' => 'Gesto de Contas POP3',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => 'Opoes de dados do actual user (Ex. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)',
         'Insert:' => 'Inserir:',
         'Security Note: You should activate %s because applications is already running!' => 'Nota de Segurana: Deve activar o %s, pois a aplicao est j em produo!',
@@ -1491,13 +1543,22 @@ sub Data {
         'OTRS DB User' => 'Utilizador de Base de Dados OTRS',
         'PhoneView' => 'Visualizao de Chamada',
         'maximal period form' => 'Maximo periodo desde',
-        'Verion' => 'Verso',
         'TicketID' => 'ID de Ticket',
         'SMIME Management' => 'Gesto de SMIME',
         'Options of the current user who requested this action (e. g. &lt;OTRS_CURRENT_UserFirstname&gt;)' => 'Opes do utilizador que requereu a aco (Ex. &lt;OTRS_CURRENT_UserFirstname&gt;)',
         'Modified' => 'Modificado',
         'Ticket selected for bulk action!' => 'Ticket seleccionado para aco em lote!',
-        'First Response' => 'Primeira Reposta',
+
+        'Link Object: %s' => '',
+        'Unlink Object: %s' => '',
+        'Linked as' => '',
+        'Can not create link with %s!' => '',
+        'Can not delete link with %s!' => '',
+        'Object already linked as %s.' => '',
+        'Priority Management' => '',
+        'Add a new Priority.' => '',
+        'Add Priority' => '',
+        'Ticket Type is required!' => '',
     };
     # $$STOP$$
     return;
